#! /usr/bin/env python
# -*- coding: utf-8 -*-

##
# SPDX-FileCopyrightText: 2010 Stephen Kelly <steveire@gmail.com>
#
# SPDX-License-Identifier: BSD-2-Clause
##

from strings_extractor_linguist import LinguistExtractStrings
import os, sys, glob, operator

if __name__ == "__main__":
  ex = LinguistExtractStrings()

  outputfile = sys.stdout

  files = reduce(operator.add, map(glob.glob, sys.argv[1:]))

  for filename in files:
    f = open(filename, "r")
    ex.translate(f, outputfile)

  outputfile.write("\n")






#! /usr/bin/env python
# -*- coding: utf-8 -*-

{% include licence|append:".py" %}
{% if baseClass %}

from PyQt4.{{ baseClass.module }} import {{ baseClass.type }}
{% endif %}

class {{ className }}({% if baseClass %}{{ baseClass.type }}{% else %}object{% endif %}):

    def __init__(self):
{% if baseClass %}
        {{ baseClass.type }}.__init__(self)
{% endif %}
        pass

{% for property in properties %}
    def {{ property.name }}(self):
        return self._{{ property.name }}
  {% if not property.readonly %}

    def {{ property.name|to_write }}(self, {{ property.name }}):
        self._{{ property.name }} = {{ property.name }}
  {% endif %}

{% endfor %}
{% with "true" as default %}
  {% for method in methods %}
    def {{ method.name }}(self{% include "args.py" %}):
        pass

  {% endfor %}
{% endwith %}
